#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-api
version:              2.11.5
visibility:           public
id:                   hspec-api-2.11.5-IFd2Iq0eJS72UCLqz4U2Oq
key:                  hspec-api-2.11.5-IFd2Iq0eJS72UCLqz4U2Oq
license:              MIT
copyright:            (c) 2022-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            stable
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package provides a stable API that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  305fe62b5fc359cf0ea40e1533cbdfb9
exposed:              True
exposed-modules:
    Test.Hspec.Api.Format.V1 Test.Hspec.Api.Format.V2
    Test.Hspec.Api.Formatters.V1 Test.Hspec.Api.Formatters.V2
    Test.Hspec.Api.Formatters.V3

hidden-modules:
    Test.Hspec.Api.Format.V1.Internal Test.Hspec.Api.Format.V2.Config

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-api-2.11.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-api-2.11.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-api-2.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-api
hs-libraries:         HShspec-api-2.11.5-IFd2Iq0eJS72UCLqz4U2Oq
depends:
    base-4.18.2.1 hspec-core-2.11.5-JHeNoGhYVAoBnugWWsTDE6
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-hspec-api/html/hspec-api.haddock
haddock-html:         /usr/share/doc/haskell-hspec-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

